@@ -58,7 +58,7 @@
 #' will ignore all novel levels. This argument does not apply to ordered
 #' factors. Novel levels are not allowed in ordered factors because the
 #' level ordering is a critical part of the type.
-#' 
+#'
 #' @inheritParams validate_column_names
 #'
 #' @return
@@ -154,7 +154,13 @@
 #' # Novel level is kept
 #' levels(test4_kept$Species)
 #' @export
-scream <- function(data, ptype, allow_novel_levels = FALSE, ..., call = current_env()) {
+scream <- function(
+  data,
+  ptype,
+  allow_novel_levels = FALSE,
+  ...,
+  call = current_env()
+) {
   check_dots_empty0(...)
   vec_assert(allow_novel_levels, ptype = logical(), size = 1L, call = call)
 
