@@ -39,8 +39,16 @@ test_that("can forge multivariate formulas", {
   expect_equal(xx1$outcomes, xx3$outcomes)
 
   y1 <- mold(log(num_2) + poly(num_2, degree = 2) ~ fac_1, example_train)
-  y2 <- mold(log(num_2) + poly(num_2, degree = 2) ~ fac_1, example_train, blueprint = sparse_bp)
-  y3 <- mold(log(num_2) + poly(num_2, degree = 2) ~ fac_1, example_train, blueprint = matrix_bp)
+  y2 <- mold(
+    log(num_2) + poly(num_2, degree = 2) ~ fac_1,
+    example_train,
+    blueprint = sparse_bp
+  )
+  y3 <- mold(
+    log(num_2) + poly(num_2, degree = 2) ~ fac_1,
+    example_train,
+    blueprint = matrix_bp
+  )
   yy1 <- forge(example_train, y1$blueprint, outcomes = TRUE)
   yy2 <- forge(example_train, y2$blueprint, outcomes = TRUE)
   yy3 <- forge(example_train, y3$blueprint, outcomes = TRUE)
@@ -94,7 +102,10 @@ test_that("forging with `indicators = 'none'` works with numeric interactions",
   x2 <- mold(
     fac_1 ~ num_2:num_1,
     example_train,
-    blueprint = default_formula_blueprint(indicators = "none", composition = "dgCMatrix")
+    blueprint = default_formula_blueprint(
+      indicators = "none",
+      composition = "dgCMatrix"
+    )
   )
 
   xx2 <- forge(example_train, x2$blueprint)
@@ -131,20 +142,24 @@ test_that("asking for the outcome when it isn't there fails", {
   example_train2 <- example_train
   example_train2$fac_1 <- NULL
 
-  expect_error(
-    forge(example_train2, x1$blueprint, outcomes = TRUE),
-    "The following required columns"
+  expect_snapshot(
+    error = TRUE,
+    forge(example_train2, x1$blueprint, outcomes = TRUE)
   )
-  expect_error(
-    forge(example_train2, x2$blueprint, outcomes = TRUE),
-    "The following required columns"
+  expect_snapshot(
+    error = TRUE,
+    forge(example_train2, x2$blueprint, outcomes = TRUE)
   )
 })
 
 test_that("can use special inline functions", {
   bp <- default_formula_blueprint(composition = "matrix")
   x1 <- mold(log(num_1) ~ poly(num_1, degree = 2), example_train)
-  x2 <- mold(log(num_1) ~ poly(num_1, degree = 2), example_train, blueprint = bp)
+  x2 <- mold(
+    log(num_1) ~ poly(num_1, degree = 2),
+    example_train,
+    blueprint = bp
+  )
   xx1 <- forge(example_train, x1$blueprint, outcomes = TRUE)
   xx2 <- forge(example_train, x2$blueprint, outcomes = TRUE)
 
@@ -178,14 +193,8 @@ test_that("new_data can be a matrix", {
   x2 <- mold(fac_1 ~ num_1, example_train, blueprint = bp)
   example_train_mat <- as.matrix(example_train[, "num_1", drop = FALSE])
 
-  expect_error(
-    xx1 <- forge(example_train_mat, x1$blueprint),
-    NA
-  )
-  expect_error(
-    xx2 <- forge(example_train_mat, x2$blueprint),
-    NA
-  )
+  expect_no_error(xx1 <- forge(example_train_mat, x1$blueprint))
+  expect_no_error(xx2 <- forge(example_train_mat, x2$blueprint))
 
   sep_len <- example_train$num_1
 
@@ -204,13 +213,13 @@ test_that("new_data can only be a data frame / matrix", {
   x1 <- mold(fac_1 ~ num_1, example_train)
   x2 <- mold(fac_1 ~ num_1, example_train, blueprint = bp)
 
-  expect_error(
-    forge("hi", x1$blueprint),
-    "The class of `new_data`, 'character'"
+  expect_snapshot(
+    error = TRUE,
+    forge("hi", x1$blueprint)
   )
-  expect_error(
-    forge("hi", x2$blueprint),
-    "The class of `new_data`, 'character'"
+  expect_snapshot(
+    error = TRUE,
+    forge("hi", x2$blueprint)
   )
 })
 
@@ -219,22 +228,22 @@ test_that("missing predictor columns fail appropriately", {
   x1 <- mold(fac_1 ~ num_1 + num_2, example_train)
   x2 <- mold(fac_1 ~ num_1 + num_2, example_train, blueprint = bp)
 
-  expect_error(
-    forge(example_train[, 1, drop = FALSE], x1$blueprint),
-    "num_2"
+  expect_snapshot(
+    error = TRUE,
+    forge(example_train[, 1, drop = FALSE], x1$blueprint)
   )
-  expect_error(
-    forge(example_train[, 1, drop = FALSE], x2$blueprint),
-    "num_2"
+  expect_snapshot(
+    error = TRUE,
+    forge(example_train[, 1, drop = FALSE], x2$blueprint)
   )
 
-  expect_error(
-    forge(example_train[, 3, drop = FALSE], x1$blueprint),
-    "'num_1', 'num_2'"
+  expect_snapshot(
+    error = TRUE,
+    forge(example_train[, 3, drop = FALSE], x1$blueprint)
   )
-  expect_error(
-    forge(example_train[, 3, drop = FALSE], x2$blueprint),
-    "'num_1', 'num_2'"
+  expect_snapshot(
+    error = TRUE,
+    forge(example_train[, 3, drop = FALSE], x2$blueprint)
   )
 })
 
@@ -253,15 +262,8 @@ test_that("novel predictor levels are caught", {
   x1 <- mold(y ~ f, dat)
   x2 <- mold(y ~ f, dat, blueprint = bp)
 
-
-  expect_warning(
-    xx1 <- forge(new, x1$blueprint),
-    "Novel levels found in column 'f': 'e'"
-  )
-  expect_warning(
-    xx2 <- forge(new, x2$blueprint),
-    "Novel levels found in column 'f': 'e'"
-  )
+  expect_snapshot(xx1 <- forge(new, x1$blueprint))
+  expect_snapshot(xx2 <- forge(new, x2$blueprint))
 
   expect_equal(
     xx1$predictors[[5, 1]],
@@ -271,6 +273,14 @@ test_that("novel predictor levels are caught", {
     unname(xx2$predictors[5, 1]),
     NA_real_
   )
+
+  new_multiple <- data.frame(
+    y = 1:6,
+    f = factor(letters[1:6])
+  )
+  x3 <- mold(y ~ f, dat)
+
+  expect_snapshot(xx3 <- forge(new_multiple, x3$blueprint))
 })
 
 test_that("novel predictor levels can be ignored", {
@@ -285,19 +295,17 @@ test_that("novel predictor levels can be ignored", {
   )
 
   bp1 <- default_formula_blueprint(allow_novel_levels = TRUE)
-  bp2 <- default_formula_blueprint(allow_novel_levels = TRUE, composition = "dgCMatrix")
+  bp2 <- default_formula_blueprint(
+    allow_novel_levels = TRUE,
+    composition = "dgCMatrix"
+  )
 
   x1 <- mold(y ~ f, dat, blueprint = bp1)
   x2 <- mold(y ~ f, dat, blueprint = bp2)
 
-  expect_warning(
-    xx1 <- forge(new, x1$blueprint),
-    NA
-  )
-  expect_warning(
-    xx2 <- forge(new, x2$blueprint),
-    NA
-  )
+  # Silent
+  expect_snapshot(xx1 <- forge(new, x1$blueprint))
+  expect_snapshot(xx2 <- forge(new, x2$blueprint))
 
   expect_equal(
     xx1$predictors[[5, 5]],
@@ -360,7 +368,10 @@ test_that("novel predictor levels without any data are kept when novel levels ar
   new <- new[1:4, ]
 
   bp1 <- default_formula_blueprint(allow_novel_levels = TRUE)
-  bp2 <- default_formula_blueprint(allow_novel_levels = TRUE, composition = "dgCMatrix")
+  bp2 <- default_formula_blueprint(
+    allow_novel_levels = TRUE,
+    composition = "dgCMatrix"
+  )
 
   x1 <- mold(y ~ f, dat, blueprint = bp1)
   x2 <- mold(y ~ f, dat, blueprint = bp2)
@@ -397,14 +408,8 @@ test_that("novel levels are handled correctly when the new column is a character
   x1 <- mold(y ~ f, dat)
   x2 <- mold(y ~ f, dat, blueprint = bp)
 
-  expect_warning(
-    xx1 <- forge(new, x1$blueprint),
-    "Novel levels found in column 'f': 'e'"
-  )
-  expect_warning(
-    xx2 <- forge(new, x2$blueprint),
-    "Novel levels found in column 'f': 'e'"
-  )
+  expect_snapshot(xx1 <- forge(new, x1$blueprint))
+  expect_snapshot(xx2 <- forge(new, x2$blueprint))
 
   expect_equal(
     xx1$predictors[[5, 1]],
@@ -477,19 +482,17 @@ test_that("novel levels are ignored correctly when the new column is a character
   )
 
   bp1 <- default_formula_blueprint(allow_novel_levels = TRUE)
-  bp2 <- default_formula_blueprint(allow_novel_levels = TRUE, composition = "dgCMatrix")
+  bp2 <- default_formula_blueprint(
+    allow_novel_levels = TRUE,
+    composition = "dgCMatrix"
+  )
 
   x1 <- mold(y ~ f, dat, blueprint = bp1)
   x2 <- mold(y ~ f, dat, blueprint = bp2)
 
-  expect_warning(
-    xx1 <- forge(new, x1$blueprint),
-    NA
-  )
-  expect_warning(
-    xx2 <- forge(new, x2$blueprint),
-    NA
-  )
+  # Silent
+  expect_snapshot(xx1 <- forge(new, x1$blueprint))
+  expect_snapshot(xx2 <- forge(new, x2$blueprint))
 
   expect_equal(
     xx1$predictors[[5, 5]],
@@ -532,8 +535,14 @@ test_that("novel ordered factor predictor levels are never allowed", {
     f = ordered(letters[1:5])
   )
 
-  bp1 <- default_formula_blueprint(indicators = "none", allow_novel_levels = FALSE)
-  bp2 <- default_formula_blueprint(indicators = "none", allow_novel_levels = TRUE)
+  bp1 <- default_formula_blueprint(
+    indicators = "none",
+    allow_novel_levels = FALSE
+  )
+  bp2 <- default_formula_blueprint(
+    indicators = "none",
+    allow_novel_levels = TRUE
+  )
 
   x1 <- mold(y ~ f, dat, blueprint = bp1)
   x2 <- mold(y ~ f, dat, blueprint = bp2)
@@ -559,8 +568,14 @@ test_that("ordered factor predictors with different level ordering is an error",
     f = ordered(letters[1:4], levels = letters[c(1:2, 4, 3)])
   )
 
-  bp1 <- default_formula_blueprint(indicators = "none", allow_novel_levels = FALSE)
-  bp2 <- default_formula_blueprint(indicators = "none", allow_novel_levels = TRUE)
+  bp1 <- default_formula_blueprint(
+    indicators = "none",
+    allow_novel_levels = FALSE
+  )
+  bp2 <- default_formula_blueprint(
+    indicators = "none",
+    allow_novel_levels = TRUE
+  )
 
   x1 <- mold(y ~ f, dat, blueprint = bp1)
   x2 <- mold(y ~ f, dat, blueprint = bp2)
@@ -590,14 +605,8 @@ test_that("novel outcome levels are caught", {
   x1 <- mold(f ~ y, dat)
   x2 <- mold(f ~ y, dat, blueprint = bp)
 
-  expect_warning(
-    xx1 <- forge(new, x1$blueprint, outcomes = TRUE),
-    "Novel levels found in column 'f': 'e'"
-  )
-  expect_warning(
-    xx2 <- forge(new, x2$blueprint, outcomes = TRUE),
-    "Novel levels found in column 'f': 'e'"
-  )
+  expect_snapshot(xx1 <- forge(new, x1$blueprint, outcomes = TRUE))
+  expect_snapshot(xx2 <- forge(new, x2$blueprint, outcomes = TRUE))
 
   expect_equal(
     xx1$outcomes[[5, 1]],
@@ -621,19 +630,16 @@ test_that("novel outcome levels are always caught, even if `allow_novel_levels =
   )
 
   bp1 <- default_formula_blueprint(allow_novel_levels = TRUE)
-  bp2 <- default_formula_blueprint(allow_novel_levels = TRUE, composition = "matrix")
+  bp2 <- default_formula_blueprint(
+    allow_novel_levels = TRUE,
+    composition = "matrix"
+  )
 
   x1 <- mold(f ~ y, dat, blueprint = bp1)
   x2 <- mold(f ~ y, dat, blueprint = bp2)
 
-  expect_warning(
-    xx1 <- forge(new, x1$blueprint, outcomes = TRUE),
-    "Novel levels found in column 'f': 'e'"
-  )
-  expect_warning(
-    xx2 <- forge(new, x2$blueprint, outcomes = TRUE),
-    "Novel levels found in column 'f': 'e'"
-  )
+  expect_snapshot(xx1 <- forge(new, x1$blueprint, outcomes = TRUE))
+  expect_snapshot(xx2 <- forge(new, x2$blueprint, outcomes = TRUE))
 
   expect_equal(
     xx1$outcomes[[5, 1]],
@@ -667,14 +673,9 @@ test_that("missing predictor levels are restored silently", {
   x1 <- mold(y ~ f, dat)
   x2 <- mold(y ~ f, dat, blueprint = bp)
 
-  expect_warning(
-    xx1 <- forge(new, x1$blueprint),
-    NA
-  )
-  expect_warning(
-    xx2 <- forge(new, x2$blueprint),
-    NA
-  )
+  # Silent
+  expect_snapshot(xx1 <- forge(new, x1$blueprint))
+  expect_snapshot(xx2 <- forge(new, x2$blueprint))
 
   expect_equal(
     colnames(xx1$predictors),
@@ -685,14 +686,9 @@ test_that("missing predictor levels are restored silently", {
     c("fa", "fb", "fc", "fd")
   )
 
-  expect_warning(
-    yy1 <- forge(new2, x1$blueprint),
-    NA
-  )
-  expect_warning(
-    yy2 <- forge(new2, x2$blueprint),
-    NA
-  )
+  # Silent
+  expect_snapshot(yy1 <- forge(new2, x1$blueprint))
+  expect_snapshot(yy2 <- forge(new2, x2$blueprint))
 
   expect_equal(
     colnames(yy1$predictors),
@@ -710,8 +706,14 @@ test_that("missing ordered factor levels are an error", {
     f = ordered(letters[1:4])
   )
 
-  bp1 <- default_formula_blueprint(indicators = "none", allow_novel_levels = FALSE)
-  bp2 <- default_formula_blueprint(indicators = "none", allow_novel_levels = TRUE)
+  bp1 <- default_formula_blueprint(
+    indicators = "none",
+    allow_novel_levels = FALSE
+  )
+  bp2 <- default_formula_blueprint(
+    indicators = "none",
+    allow_novel_levels = TRUE
+  )
 
   x1 <- mold(y ~ f, dat, blueprint = bp1)
   x2 <- mold(y ~ f, dat, blueprint = bp2)
@@ -744,17 +746,24 @@ test_that("can be both missing levels and have new levels", {
 
   bp1 <- default_formula_blueprint(indicators = "none")
   bp2 <- default_formula_blueprint(indicators = "none", composition = "matrix")
+
   x1 <- mold(y ~ f, dat, blueprint = bp1)
-  expect_error(
-    x2 <- mold(y ~ f, dat, blueprint = bp2),
-    "cannot convert to matrix"
+  expect_snapshot(error = TRUE, {
+    mold(y ~ f, dat, blueprint = bp2)
+  })
+
+  dat_2f <- data.frame(
+    y = 1:4,
+    f = factor(letters[1:4]),
+    f_2 = factor(letters[5:8])
   )
 
+  expect_snapshot(error = TRUE, {
+    mold(y ~ f + f_2, dat_2f, blueprint = bp2)
+  })
+
   # Warning for the extra level
-  expect_warning(
-    xx <- forge(new, x1$blueprint),
-    "Novel levels found in column 'f': 'e'"
-  )
+  expect_snapshot(xx <- forge(new, x1$blueprint))
 
   expect_equal(
     levels(xx$predictors$f),
@@ -773,14 +782,15 @@ test_that("can be both missing levels and have new levels that get ignored", {
     f = factor(letters[c(1:3, 5)])
   )
 
-  blueprint <- default_formula_blueprint(indicators = "none", allow_novel_levels = TRUE)
+  blueprint <- default_formula_blueprint(
+    indicators = "none",
+    allow_novel_levels = TRUE
+  )
 
   x <- mold(y ~ f, dat, blueprint = blueprint)
 
-  expect_warning(
-    xx <- forge(new, x$blueprint),
-    NA
-  )
+  # Silent
+  expect_snapshot(xx <- forge(new, x$blueprint))
 
   # Order of levels comes from `new` first, then `dat`
   expect_equal(
@@ -804,10 +814,7 @@ test_that("`NA` factor data never triggers a novel level warning (#131)", {
 
   x <- mold(y ~ f, dat, blueprint = blueprint)
 
-  expect_warning(
-    xx <- forge(new, x$blueprint),
-    NA
-  )
+  expect_snapshot(xx <- forge(new, x$blueprint))
 
   expect_identical(
     xx$predictors$f,
@@ -819,12 +826,15 @@ test_that("new data classes are caught", {
   example_train2 <- example_train
   example_train2$fac_1 <- as.character(example_train2$fac_1)
 
-  x <- mold(num_1 ~ fac_1, example_train, blueprint = default_formula_blueprint(indicators = "none"))
+  x <- mold(
+    num_1 ~ fac_1,
+    example_train,
+    blueprint = default_formula_blueprint(indicators = "none")
+  )
 
   # Silently recover character -> factor
-  expect_error(
-    x_example_train2 <- forge(example_train2, x$blueprint),
-    NA
+  expect_no_error(
+    x_example_train2 <- forge(example_train2, x$blueprint)
   )
 
   expect_s3_class(
@@ -834,9 +844,8 @@ test_that("new data classes are caught", {
 
   xx <- mold(fac_1 ~ num_1, example_train)
 
-  expect_error(
-    xx_example_train2 <- forge(example_train2, xx$blueprint, outcomes = TRUE),
-    NA
+  expect_no_error(
+    xx_example_train2 <- forge(example_train2, xx$blueprint, outcomes = TRUE)
   )
 
   expect_s3_class(
@@ -853,30 +862,26 @@ test_that("new data classes can interchange integer/numeric", {
   x1 <- mold(fac_1 ~ num_1, example_train)
   x2 <- mold(fac_1 ~ num_1, example_train, blueprint = bp)
 
-  expect_error(
-    forge(example_train2, x1$blueprint),
-    NA
-  )
-  expect_error(
-    forge(example_train2, x2$blueprint),
-    NA
-  )
+  expect_no_error(forge(example_train2, x1$blueprint))
+  expect_no_error(forge(example_train2, x2$blueprint))
 
   x3 <- mold(num_1 ~ fac_1, example_train)
   x4 <- mold(num_1 ~ fac_1, example_train, blueprint = bp)
 
-  expect_error(
-    forge(example_train2, x3$blueprint, outcomes = TRUE),
-    NA
+  expect_no_error(
+    forge(example_train2, x3$blueprint, outcomes = TRUE)
   )
-  expect_error(
-    forge(example_train2, x4$blueprint, outcomes = TRUE),
-    NA
+  expect_no_error(
+    forge(example_train2, x4$blueprint, outcomes = TRUE)
   )
 })
 
 test_that("intercepts can still be forged on when not using indicators (i.e. model.matrix())", {
-  x <- mold(num_2 ~ fac_1, example_train, blueprint = default_formula_blueprint(intercept = TRUE, indicators = "none"))
+  x <- mold(
+    num_2 ~ fac_1,
+    example_train,
+    blueprint = default_formula_blueprint(intercept = TRUE, indicators = "none")
+  )
   xx <- forge(example_train, x$blueprint)
 
   expect_true(
@@ -923,8 +928,14 @@ test_that("character predictors are treated as factors when `indicators` is not
 
   bp1 <- default_formula_blueprint(indicators = "traditional")
   bp2 <- default_formula_blueprint(indicators = "one_hot")
-  bp3 <- default_formula_blueprint(indicators = "traditional", composition = "matrix")
-  bp4 <- default_formula_blueprint(indicators = "one_hot", composition = "matrix")
+  bp3 <- default_formula_blueprint(
+    indicators = "traditional",
+    composition = "matrix"
+  )
+  bp4 <- default_formula_blueprint(
+    indicators = "one_hot",
+    composition = "matrix"
+  )
 
   res1 <- mold(y ~ x + z, df, blueprint = bp1)
   res2 <- mold(y ~ x + z, df, blueprint = bp2)
@@ -978,6 +989,80 @@ test_that("character predictors are left as characters when `indicators` is 'non
   expect_true(is.character(x$predictors$z))
 })
 
+test_that("`new_data` uses the character predictor column's observed levels", {
+  df1 <- tibble(x = c("a", "b", "c"))
+  df2 <- tibble(x = c("a", "c"))
+
+  bp1 <- default_formula_blueprint(indicators = "traditional")
+  bp2 <- default_formula_blueprint(indicators = "one_hot")
+
+  x <- mold(~x, df1, blueprint = bp1)
+  out <- forge(df2, x$blueprint)
+  expect_named(out$predictors, c("xa", "xb", "xc"))
+
+  x <- mold(~x, df1, blueprint = bp2)
+  out <- forge(df2, x$blueprint)
+  expect_named(out$predictors, c("xa", "xb", "xc"))
+})
+
+test_that("`allow_novel_levels` works right with character predictors", {
+  df1 <- tibble(x = c("a", "b", "c"))
+  df2 <- tibble(x = c("a", "d"))
+
+  bp <- default_formula_blueprint(allow_novel_levels = FALSE)
+  x <- mold(~x, df1, blueprint = bp)
+  expect_snapshot({
+    # Novel level warning about `d`
+    out <- forge(df2, x$blueprint)
+  })
+  expect_named(out$predictors, c("xa", "xb", "xc"))
+
+  bp <- default_formula_blueprint(
+    allow_novel_levels = FALSE,
+    indicators = "none"
+  )
+  x <- mold(~x, df1, blueprint = bp)
+  out <- forge(df2, x$blueprint)
+  expect_named(out$predictors, "x")
+  expect_identical(out$predictors$x, c("a", "d"))
+
+  bp <- default_formula_blueprint(allow_novel_levels = TRUE)
+  x <- mold(~x, df1, blueprint = bp)
+  out <- forge(df2, x$blueprint)
+  expect_named(out$predictors, c("xa", "xd", "xb", "xc"))
+})
+
+test_that("character vectors in `new_data` with 1 contrast level works properly with `indicators = traditional/one_hot` (#213)", {
+  df1 <- tibble(x = c("a", "b"))
+  df2 <- tibble(x = "a")
+
+  bp <- default_formula_blueprint(indicators = "traditional")
+  x <- mold(~x, df1, blueprint = bp)
+  out <- forge(df2, x$blueprint)
+  expect_named(out$predictors, c("xa", "xb"))
+  expect_identical(out$predictors$xa, 1)
+  expect_identical(out$predictors$xb, 0)
+
+  bp <- default_formula_blueprint(indicators = "one_hot")
+  x <- mold(~x, df1, blueprint = bp)
+  out <- forge(df2, x$blueprint)
+  expect_named(out$predictors, c("xa", "xb"))
+  expect_identical(out$predictors$xa, 1)
+  expect_identical(out$predictors$xb, 0)
+})
+
+test_that("character vectors in `new_data` with 1 contrast level works properly with `indicators = none` (#213)", {
+  df1 <- tibble(x = c("a", "b"))
+  df2 <- tibble(x = "a")
+
+  bp <- default_formula_blueprint(indicators = "none")
+  x <- mold(~x, df1, blueprint = bp)
+  out <- forge(df2, x$blueprint)
+
+  expect_named(out$predictors, "x")
+  expect_identical(out$predictors$x, "a")
+})
+
 test_that("`new_data` can be converted losslessly from factor to character", {
   df <- data.frame(
     y = 1:2,
@@ -992,8 +1077,14 @@ test_that("`new_data` can be converted losslessly from factor to character", {
   bp1 <- default_formula_blueprint(indicators = "none")
   bp2 <- default_formula_blueprint(indicators = "traditional")
   bp3 <- default_formula_blueprint(indicators = "one_hot")
-  bp4 <- default_formula_blueprint(indicators = "traditional", composition = "matrix")
-  bp5 <- default_formula_blueprint(indicators = "one_hot", composition = "matrix")
+  bp4 <- default_formula_blueprint(
+    indicators = "traditional",
+    composition = "matrix"
+  )
+  bp5 <- default_formula_blueprint(
+    indicators = "one_hot",
+    composition = "matrix"
+  )
 
   res1 <- mold(y ~ x + z, df, blueprint = bp1)
   res2 <- mold(y ~ x + z, df, blueprint = bp2)
